

set -ex



gdal_grid --version
gdal_rasterize --version
gdal_translate --version
gdaladdo --version
gdalenhance --version
gdalwarp --version
gdalinfo --formats
bash /var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_b3c3ptv5yl/clone/recipe/run_test.sh
exit 0
